@@ -2,4 +2,4 @@
 Import hgfind for ease of importing from package
 
 """
-from .hgfind import hgfind
+from .hgfind import WrongGeneName, hgfind
